@@ -21,6 +21,9 @@ my $process = Locale::TextDomain::OO::Extract::Process->new(
                            # project not used
 );
 
+# Skip if po file not exists. You get a default header, change later by hand.
+# If skipped check plural-forms for non English, see:
+# http://translate.sourceforge.net/wiki/l10n/pluralforms
 SLURP_EXISTING_FILES: {
     # category and project unchanged
     for my $language (@languages) {
@@ -29,6 +32,7 @@ SLURP_EXISTING_FILES: {
     }
 }
 
+# Skip if po file not exists. You get a default header, change later by hand.
 PREPARE_FOR_EXTRACTION: {
     $process->remove_all_reference;
     $process->remove_all_automatic;
@@ -139,6 +143,7 @@ msgstr "Januar"
 #. thing => 'text'
 #: files_to_extract_for_process/gettext_loc.pl:15
 msgid "This is a new {thing}."
+msgstr ""
 
 de-at/LC_MESSAGES/example1.po (clean)
 
