@@ -7,7 +7,7 @@ use Moo;
 use MooX::Types::MooseLike::Base qw(ArrayRef Str);
 use namespace::autoclean;
 
-our $VERSION = '2.004';
+our $VERSION = '2.007';
 
 extends qw(
     Locale::TextDomain::OO::Extract::Base::RegexBasedExtractor
@@ -52,7 +52,7 @@ my $category_rule
             # q{text with 0 .. n {placeholders} and/or 0 .. n escaped chars}
             ## no critic (EscapedMetacharacters)
             qr{
-                \s* ( qq? ) \{        # q curly bracket quoted
+                \s* ( qq? \{ )        # q curly bracket quoted
                 (
                     (?:
                         [^\{\}\\]     # normal text
@@ -76,6 +76,8 @@ my $start_rule = qr{
         (?:
             # Gettext::Loc, Gettext
             N? (?: loc_ | __ ) d? c? n? p? x?
+            # BabelFish::Loc
+            | N? loc_b p?
             # Maketext::Loc, Maketext::Localise, Maketext::Localize
             | N? loc (?: ali[sz]e )? (?: _mp? )?
             # Maketext
@@ -419,7 +421,34 @@ my $rules = [
         'end',
     ],
 
-    # maketext loc, localize, localize
+    # babelfish loc_b
+    'or',
+    [
+        'begin',
+        qr{ \b N? loc_b () \s* [(] }xms,
+        'and',
+        $text_rule,
+        'and',
+        $close_rule,
+        'end',
+    ],
+    'or',
+    # babelfish loc_bp
+    [
+        'begin',
+        qr{ \b N? loc_b ( p ) \s* [(] }xms,
+        'and',
+        $context_rule,
+        'and',
+        $comma_rule,
+        'and',
+        $text_rule,
+        'and',
+        $close_rule,
+        'end',
+    ],
+
+    # maketext loc, localise, localize
     'or',
     [
         'begin',
@@ -508,26 +537,32 @@ my $rules = [
     ],
 ];
 
-# remove pod and code after __END__
+# remove pod and all lines after __END__, handle different newlines
 sub preprocess {
     my $self = shift;
 
     my $content_ref = $self->content_ref;
 
+    # remove all lines after __END__
+    # replace pod without killing the line number
     my ($is_pod, $is_end);
-    ${$content_ref} = join "\n", map {
-        $_ eq '__END__'        ? do { $is_end = 1; q{} }
-        : $is_end              ? ()
-        : m{ $ = ( \w+ ) }xms  ? (
-            lc $1 eq 'cut'
-            ? do { $is_pod = 0; q{} }
-            : do { $is_pod = 1; q{} }
-        )
-        : $is_pod              ? q{}
-        : $_;
-    } split m{ \r? \n }xms, ${$content_ref};
+    ${$content_ref}
+        = join "\n",
+        map {
+            $_ eq '__END__'          ? do { $is_end = 1; q{} }
+            : $is_end                ? ()
+            : m{ \A [=] ( \w+ ) }xms ? (
+                lc $1 eq 'cut'
+                ? do { $is_pod = 0; q{} }
+                : do { $is_pod = 1; q{} }
+            )
+            : $is_pod                ? q{}
+            : $_;
+        }
+        split m{ \r? \n }xms, ${$content_ref};
 
     # replace heredoc's without killing the line number
+    # <<'...'
     REPLACE: {
         ${$content_ref} =~ s{
             << \s* ' ( \w+ ) ' ( [^\n]* ) \n
@@ -541,6 +576,8 @@ sub preprocess {
             . $2
         }xmsge and redo REPLACE;
     }
+    # <<...
+    # <<"..."
     REPLACE: {
         ${$content_ref} =~ s{
             << \s* ( ["]? ) ( \w+ ) \1 ( [^\n]* ) \n
@@ -555,29 +592,35 @@ sub preprocess {
         }xmsge and redo REPLACE;
     }
 
-    return;
+    return $self;
 }
 
-my $interpolate_escape_sequence = sub {
-    my ( $quot, $string ) = @_;
+sub interpolate_escape_sequence {
+    my ( undef, $string, $quot ) = @_;
 
     # nothing to interpolate
     defined $string
-        or return;
+        or return $string;
     defined $quot
-        or return;
-    my $is_interpolate = $quot eq q{"} || $quot eq 'qq';
+        or confess 'Quote expected';
+
+    my $is_interpolate = $quot eq q{"} || $quot eq 'qq{';
     if ( ! $is_interpolate ) {
+        # '...'
         if ( $quot eq q{'} ) {
             $string =~ s{ \\ ( ['] ) }{$1}xmsg;
             return $string;
         }
-        if ( $quot eq q{q} ) {
-            $string =~ s{ \\ ( [\{\}] ) }{$1}xmsg;
+        # q{...}
+        if ( $quot eq 'q{' ) {
+            $string =~ s{ \\ ( [\{\}] ) }{$1}xmsg; ## no critic (EscapedMetacharacters)
             return $string;
         }
+        confess "Unknown quot $quot";
     }
 
+    # "..."
+    # qq{...}
     my %char_of = (
         b => "\b",
         f => "\f",
@@ -585,7 +628,6 @@ my $interpolate_escape_sequence = sub {
         r => "\r",
         t => "\t",
     );
-    ## no critic (ComplexRegexes)
     $string =~ s{
         \\
         (?:
@@ -605,10 +647,9 @@ my $interpolate_escape_sequence = sub {
         : $2 ? "\\$2"
         :      $3
     }xmsge;
-    ## use critic (ComplexRegexes)
 
     return $string;
-};
+}
 
 sub stack_item_mapping {
     my $self = shift;
@@ -624,23 +665,31 @@ sub stack_item_mapping {
             d => sub {
                 push @{ $self->domain_stack }, $self->domain;
                 $self->domain(
-                    scalar $interpolate_escape_sequence->( splice @{$match}, 0, 2 ),
+                    scalar $self->interpolate_escape_sequence(
+                        reverse splice @{$match}, 0, 2
+                    ),
                 );
             },
             c => sub {
                 push @{ $self->category_stack }, $self->category;
                 $self->category(
-                    scalar $interpolate_escape_sequence->( splice @{$match}, 0, 2 ),
+                    scalar $self->interpolate_escape_sequence(
+                        reverse splice @{$match}, 0, 2
+                    ),
                 );
             },
             dc => sub {
                 push @{ $self->domain_stack }, $self->domain;
                 $self->domain(
-                    scalar $interpolate_escape_sequence->( splice @{$match}, 0, 2 ),
+                    scalar $self->interpolate_escape_sequence(
+                        reverse splice @{$match}, 0, 2
+                    ),
                 );
                 push @{ $self->category_stack }, $self->category;
                 $self->category(
-                    scalar $interpolate_escape_sequence->( splice @{$match}, 0, 2 ),
+                    scalar $self->interpolate_escape_sequence(
+                        reverse splice @{$match}, 0, 2
+                    ),
                 );
             },
         }->{ shift @{$match} }->();
@@ -674,21 +723,31 @@ sub stack_item_mapping {
     $self->add_message({
         reference    => ( sprintf '%s:%s', $self->filename, $_->{line_number} ),
         domain       => $extra_parameter =~ m{ d }xms
-            ? scalar $interpolate_escape_sequence->( splice @{$match}, 0, 2 )
+            ? scalar $self->interpolate_escape_sequence(
+                reverse splice @{$match}, 0, 2
+            )
             : $self->domain,
         msgctxt      => $extra_parameter =~ m{ p }xms
-            ? scalar $interpolate_escape_sequence->( splice @{$match}, 0, 2 )
+            ? scalar $self->interpolate_escape_sequence(
+                reverse splice @{$match}, 0, 2
+            )
             : undef,
-        msgid        => scalar $interpolate_escape_sequence->( splice @{$match}, 0, 2 ),
+        msgid        => scalar $self->interpolate_escape_sequence(
+            reverse splice @{$match}, 0, 2
+        ),
         msgid_plural => $extra_parameter =~ m{ n }xms
             ? do {
-                my $plural = $interpolate_escape_sequence->( splice @{$match}, 0, 2 );
+                my $plural = $self->interpolate_escape_sequence(
+                    reverse splice @{$match}, 0, 2
+                );
                 $count = shift @{$match};
                 $plural;
             }
             : undef,
         category     => $extra_parameter =~ m{ c }xms
-            ? scalar $interpolate_escape_sequence->( splice @{$match}, 0, 2 )
+            ? scalar $self->interpolate_escape_sequence(
+                reverse splice @{$match}, 0, 2
+            )
             : $self->category,
         automatic    => do {
             my $placeholders = shift @{$match};
@@ -720,7 +779,7 @@ sub extract {
         $self->stack_item_mapping;
     }
 
-    return;
+    return $self;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -733,13 +792,13 @@ __END__
 Locale::TextDomain::OO::Extract::Perl
 - Extracts internationalization data from Perl source code
 
-$Id: Perl.pm 576 2015-04-12 05:48:58Z steffenw $
+$Id: Perl.pm 621 2015-08-23 08:20:48Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/extract/trunk/lib/Locale/TextDomain/OO/Extract/Perl.pm $
 
 =head1 VERSION
 
-2.004
+2.007
 
 =head1 DESCRIPTION
 
@@ -819,6 +878,9 @@ Implemented rules:
  __dcnp('...
  __dcnpx('...
 
+ loc_b('...
+ loc_bp('...
+
  loc('...
  loc_mp('...
 
@@ -859,7 +921,7 @@ Quote and escape any text like: ' text {placeholder} \\ \' ' or q{ text {placeho
     my $extractor = Locale::TextDomain::OO::Extract::Perl->new;
     for ( @files ) {
         $extractor->clear;
-        $extractor->filename($_);
+        $extractor->filename($_);            # dir/filename for reference
         $extractor->content_ref( \( path($_)->slurp_utf8 ) );
         $exttactor->category('LC_Messages'); # set defaults or q{} is used
         $extractor->domain('default');       # set defaults or q{} is used
@@ -874,18 +936,32 @@ Quote and escape any text like: ' text {placeholder} \\ \' ' or q{ text {placeho
 All parameters are optional.
 See Locale::TextDomain::OO::Extract to replace the defaults.
 
-=head2 method preprocess
+    my $extractor = Locale::TextDomain::OO::Extract::Perl->new;
+
+=head2 method preprocess (called by method extract)
 
 This method removes the POD and all after __END__.
 
-=head2 method stack_item_mapping
+    $extractor->preprocess;
+
+=head2 method interpolate_escape_sequence (called by method extract)
+
+This method helps e.g. \n to be a real newline in string.
+
+    $string = $extractor->interpolate_escape_sequence($string, $quot);
+
+=head2 method stack_item_mapping (called by method extract)
 
 This method maps the matched stuff as lexicon item.
 
+    $extractor->stack_item_mapping;
+
 =head2 method extract
 
 This method runs the extraction.
 
+    $extractor->extract;
+
 =head1 EXAMPLE
 
 Inside of this distribution is a directory named example.
@@ -931,7 +1007,7 @@ Steffen Winkler
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2009 - 2015,
+Copyright (c) 2009 - 2017,
 Steffen Winkler
 C<< <steffenw at cpan.org> >>.
 All rights reserved.
